@@ -127,7 +127,7 @@ suggest <- function(object, strictness = 0.01, plot = FALSE){
             if(length(last_suggested_feature)){
                 final <- VIMP_features[1:last_suggested_feature]
             }else{
-                message("It seems with this suggestion criteria, nothing is left to suggest. Try loosening the the strictness and choosing a smaller strictness value. The current strictness value is: ", strictness, ifelse(interactive(), "\n"))
+                message("It seems with this suggestion criteria, nothing is left to suggest. Try loosening the the strictness and choosing a smaller strictness value. The current strictness value is: ", strictness, ifelse(interactive(), "\n", ""))
                 
                 return(NULL)
             }
